@@ -10,4 +10,5 @@
 from .exception import KaranageException
 from .connection import KaranageConnection
 from .state import StateSystem, KaranageState
-from .log import KaranageLog
+from .log import KaranageLog, GroupLogElement
+
